@@ -10,11 +10,8 @@ import random
 import tqdm
 import pickle
 
-
 parser = ConfigParser()
-cwd = os.path.dirname(os.path.abspath(__file__))
-print(cwd)
-config_file = os.path.join(cwd, 'configuration.ini')
+config_file = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'configuration.ini')
 parser.read(config_file)
 
 class Sorn(object):
